Author: markt
Date: Tue Nov 17 22:33:58 2009
New Revision: 881578

URL: http://svn.apache.org/viewvc?rev=881578&view=rev
Log:
Fix https://issues.apache.org/bugzilla/show_bug.cgi?id=48149
Correct JavaDoc typos. Patch provided by gingyang.xu

Modified:
    tomcat/trunk/java/org/apache/coyote/ActionCode.java
    tomcat/trunk/java/org/apache/coyote/ProtocolHandler.java
    tomcat/trunk/java/org/apache/coyote/Request.java
    tomcat/trunk/java/org/apache/coyote/RequestGroupInfo.java
    tomcat/trunk/java/org/apache/coyote/RequestInfo.java
    tomcat/trunk/java/org/apache/coyote/Response.java
    tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java
    tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java
    tomcat/trunk/java/org/apache/coyote/ajp/AjpProcessor.java
    tomcat/trunk/java/org/apache/coyote/ajp/AjpProtocol.java
    tomcat/trunk/java/org/apache/coyote/http11/AbstractHttp11Processor.java
    tomcat/trunk/java/org/apache/coyote/http11/AbstractInputBuffer.java
    tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java
    tomcat/trunk/java/org/apache/coyote/http11/Http11AprProcessor.java
    tomcat/trunk/java/org/apache/coyote/http11/Http11NioProcessor.java
    tomcat/trunk/java/org/apache/coyote/http11/Http11Processor.java
    tomcat/trunk/java/org/apache/coyote/http11/InternalAprInputBuffer.java
    tomcat/trunk/java/org/apache/coyote/http11/InternalAprOutputBuffer.java
    tomcat/trunk/java/org/apache/coyote/http11/InternalInputBuffer.java
    tomcat/trunk/java/org/apache/coyote/http11/InternalNioInputBuffer.java
    tomcat/trunk/java/org/apache/coyote/http11/InternalNioOutputBuffer.java
    tomcat/trunk/java/org/apache/coyote/http11/InternalOutputBuffer.java
    tomcat/trunk/java/org/apache/coyote/http11/filters/VoidInputFilter.java
    tomcat/trunk/java/org/apache/el/parser/AstValue.java
    tomcat/trunk/java/org/apache/el/parser/ParseException.java

Modified: tomcat/trunk/java/org/apache/coyote/ActionCode.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/ActionCode.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/ActionCode.java (original)
+++ tomcat/trunk/java/org/apache/coyote/ActionCode.java Tue Nov 17 22:33:58 2009
@@ -191,7 +191,7 @@
         this.code=code;
     }
 
-    /** Action id, useable in switches and table indexes
+    /** Action id, usable in switches and table indexes
      */
     public int getCode() {
         return code;

Modified: tomcat/trunk/java/org/apache/coyote/ProtocolHandler.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/ProtocolHandler.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/ProtocolHandler.java (original)
+++ tomcat/trunk/java/org/apache/coyote/ProtocolHandler.java Tue Nov 17 
22:33:58 2009
@@ -25,8 +25,8 @@
  * Processor is single threaded and specific to stream-based protocols,
  * will not fit Jk protocols like JNI.
  *
- * This is the main interface to be implemented by a coyoute connector.
- * Adapter is the main interface to be impleneted by a coyote servlet 
container.
+ * This is the main interface to be implemented by a coyote connector.
+ * Adapter is the main interface to be implemented by a coyote servlet 
container.
  *
  * @author Remy Maucherat
  * @author Costin Manolache

Modified: tomcat/trunk/java/org/apache/coyote/Request.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/Request.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/Request.java (original)
+++ tomcat/trunk/java/org/apache/coyote/Request.java Tue Nov 17 22:33:58 2009
@@ -140,7 +140,7 @@
     private ActionHook hook;
 
     private int bytesRead=0;
-    // Time of the request - usefull to avoid repeated calls to 
System.currentTime
+    // Time of the request - useful to avoid repeated calls to 
System.currentTime
     private long startTime = 0L;
     private int available = 0;
 
@@ -149,9 +149,9 @@
 
 
     /**
-     * Get the instance id (or JVM route). Curently Ajp is sending it with each
+     * Get the instance id (or JVM route). Currently Ajp is sending it with 
each
      * request. In future this should be fixed, and sent only once ( or
-     * 'negociated' at config time so both tomcat and apache share the same 
name.
+     * 'negotiated' at config time so both tomcat and apache share the same 
name.
      * 
      * @return the instance id
      */

Modified: tomcat/trunk/java/org/apache/coyote/RequestGroupInfo.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/RequestGroupInfo.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/RequestGroupInfo.java (original)
+++ tomcat/trunk/java/org/apache/coyote/RequestGroupInfo.java Tue Nov 17 
22:33:58 2009
@@ -20,7 +20,7 @@
 import java.util.ArrayList;
 
 /** This can be moved to top level ( eventually with a better name ).
- *  It is currently used only as a JMX artifact, to agregate the data
+ *  It is currently used only as a JMX artifact, to aggregate the data
  *  collected from each RequestProcessor thread.
  */
 public class RequestGroupInfo {

Modified: tomcat/trunk/java/org/apache/coyote/RequestInfo.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/RequestInfo.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/RequestInfo.java (original)
+++ tomcat/trunk/java/org/apache/coyote/RequestInfo.java Tue Nov 17 22:33:58 
2009
@@ -23,7 +23,7 @@
 /**
  * Structure holding the Request and Response objects. It also holds 
statistical
  * informations about request processing and provide management informations
- * about the requests beeing processed.
+ * about the requests being processed.
  *
  * Each thread uses a Request/Response pair that is recycled on each request.
  * This object provides a place to collect global low-level statistics - 
without
@@ -68,7 +68,7 @@
     ObjectName rpName;
 
     // -------------------- Information about the current request  -----------
-    // This is usefull for long-running requests only
+    // This is useful for long-running requests only
 
     public String getMethod() {
         return req.method().toString();

Modified: tomcat/trunk/java/org/apache/coyote/Response.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/Response.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/Response.java (original)
+++ tomcat/trunk/java/org/apache/coyote/Response.java Tue Nov 17 22:33:58 2009
@@ -389,7 +389,7 @@
     }
 
     /**
-     * Called explicitely by user to set the Content-Language and
+     * Called explicitly by user to set the Content-Language and
      * the default encoding
      */
     public void setLocale(Locale locale) {
@@ -427,7 +427,7 @@
      * of the response. This method must be called prior to writing output
      * using getWriter().
      *
-     * @param charset String containing the name of the chararacter encoding.
+     * @param charset String containing the name of the character encoding.
      */
     public void setCharacterEncoding(String charset) {
 

Modified: tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java (original)
+++ tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProcessor.java Tue Nov 17 
22:33:58 2009
@@ -1295,7 +1295,7 @@
             }
 
             int len = chunk.getLength();
-            // 4 - hardcoded, byte[] marshalling overhead
+            // 4 - hardcoded, byte[] marshaling overhead
             // Adjust allowed size if packetSize != default 
(Constants.MAX_PACKET_SIZE)
             int chunkSize = Constants.MAX_SEND_SIZE + packetSize - 
Constants.MAX_PACKET_SIZE;
             int off = 0;

Modified: tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java (original)
+++ tomcat/trunk/java/org/apache/coyote/ajp/AjpAprProtocol.java Tue Nov 17 
22:33:58 2009
@@ -99,7 +99,7 @@
 
 
     /**
-     * Adapter which will process the requests recieved by this endpoint.
+     * Adapter which will process the requests received by this endpoint.
      */
     private Adapter adapter;
     

Modified: tomcat/trunk/java/org/apache/coyote/ajp/AjpProcessor.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/ajp/AjpProcessor.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/ajp/AjpProcessor.java (original)
+++ tomcat/trunk/java/org/apache/coyote/ajp/AjpProcessor.java Tue Nov 17 
22:33:58 2009
@@ -1233,7 +1233,7 @@
             }
 
             int len = chunk.getLength();
-            // 4 - hardcoded, byte[] marshalling overhead
+            // 4 - hardcoded, byte[] marshaling overhead
             // Adjust allowed size if packetSize != default 
(Constants.MAX_PACKET_SIZE)
             int chunkSize = Constants.MAX_SEND_SIZE + packetSize - 
Constants.MAX_PACKET_SIZE;
             int off = 0;

Modified: tomcat/trunk/java/org/apache/coyote/ajp/AjpProtocol.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/ajp/AjpProtocol.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/ajp/AjpProtocol.java (original)
+++ tomcat/trunk/java/org/apache/coyote/ajp/AjpProtocol.java Tue Nov 17 
22:33:58 2009
@@ -100,7 +100,7 @@
 
 
     /**
-     * Adapter which will process the requests recieved by this endpoint.
+     * Adapter which will process the requests received by this endpoint.
      */
     private Adapter adapter;
     

Modified: 
tomcat/trunk/java/org/apache/coyote/http11/AbstractHttp11Processor.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/AbstractHttp11Processor.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/AbstractHttp11Processor.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/AbstractHttp11Processor.java Tue 
Nov 17 22:33:58 2009
@@ -94,7 +94,7 @@
 
 
     /**
-     * Content delimitator for the request (if false, the connection will
+     * Content delimiter for the request (if false, the connection will
      * be closed at the end of the request).
      */
     protected boolean contentDelimitation = true;
@@ -179,7 +179,7 @@
 
 
     /**
-     * Minimum contentsize to make compression.
+     * Minimum content size to make compression.
      */
     protected int compressionMinSize = 2048;
 
@@ -294,7 +294,7 @@
     }
 
     /**
-     * Add a mime-type which will be compressable
+     * Add a mime-type which will be compressible
      * The mime-type String will be exactly matched
      * in the response mime-type header .
      *
@@ -307,7 +307,7 @@
 
 
     /**
-     * Set compressable mime-type list (this method is best when used with
+     * Set compressible mime-type list (this method is best when used with
      * a large number of connectors, where it would be better to have all of
      * them referenced a single array).
      */
@@ -642,7 +642,7 @@
             || (acceptEncodingMB.indexOf("gzip") == -1))
             return false;
 
-        // Check if content is not allready gzipped
+        // Check if content is not already gzipped
         MessageBytes contentEncodingMB =
             response.getMimeHeaders().getValue("Content-Encoding");
 
@@ -650,7 +650,7 @@
             && (contentEncodingMB.indexOf("gzip") != -1))
             return false;
 
-        // If force mode, allways compress (test purposes only)
+        // If force mode, always compress (test purposes only)
         if (compressionLevel == 2)
            return true;
 
@@ -668,7 +668,7 @@
             }
         }
 
-        // Check if suffisant len to trig the compression
+        // Check if sufficient length to trigger the compression
         long contentLength = response.getContentLengthLong();
         if ((contentLength == -1)
             || (contentLength > compressionMinSize)) {

Modified: tomcat/trunk/java/org/apache/coyote/http11/AbstractInputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/AbstractInputBuffer.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/AbstractInputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/AbstractInputBuffer.java Tue Nov 
17 22:33:58 2009
@@ -295,7 +295,7 @@
     /**
      * End request (consumes leftover bytes).
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     public void endRequest()
         throws IOException {

Modified: tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/AbstractOutputBuffer.java Tue 
Nov 17 22:33:58 2009
@@ -181,7 +181,7 @@
      * 
      * @param chunk byte chunk
      * @return number of bytes written
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     public int doWrite(ByteChunk chunk, Response res) 
         throws IOException {
@@ -208,7 +208,7 @@
     /**
      * Flush the response.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     public void flush()
         throws IOException {
@@ -282,7 +282,7 @@
     /**
      * End request.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     public void endRequest()
         throws IOException {
@@ -434,7 +434,7 @@
     
     
     /**
-     * This method will write the contents of the specyfied message bytes 
+     * This method will write the contents of the specified message bytes 
      * buffer to the output stream, without filtering. This method is meant to
      * be used to write the response header.
      * 
@@ -456,7 +456,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied message bytes 
+     * This method will write the contents of the specified message bytes 
      * buffer to the output stream, without filtering. This method is meant to
      * be used to write the response header.
      * 
@@ -473,7 +473,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied char 
+     * This method will write the contents of the specified char 
      * buffer to the output stream, without filtering. This method is meant to
      * be used to write the response header.
      * 
@@ -502,7 +502,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied byte 
+     * This method will write the contents of the specified byte 
      * buffer to the output stream, without filtering. This method is meant to
      * be used to write the response header.
      * 
@@ -518,7 +518,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied String to the 
+     * This method will write the contents of the specified String to the 
      * output stream, without filtering. This method is meant to be used to 
      * write the response header.
      * 

Modified: tomcat/trunk/java/org/apache/coyote/http11/Http11AprProcessor.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/Http11AprProcessor.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/Http11AprProcessor.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/Http11AprProcessor.java Tue Nov 
17 22:33:58 2009
@@ -179,7 +179,7 @@
 
 
     /**
-     * Content delimitator for the request (if false, the connection will
+     * Content delimiter for the request (if false, the connection will
      * be closed at the end of the request).
      */
     protected boolean contentDelimitation = true;
@@ -271,7 +271,7 @@
 
 
     /**
-     * Minimum contentsize to make compression.
+     * Minimum content size to make compression.
      */
     protected int compressionMinSize = 2048;
 
@@ -412,7 +412,7 @@
     }
 
     /**
-     * Add a mime-type which will be compressable
+     * Add a mime-type which will be compressible
      * The mime-type String will be exactly matched
      * in the response mime-type header .
      *
@@ -425,7 +425,7 @@
 
 
     /**
-     * Set compressable mime-type list (this method is best when used with
+     * Set compressible mime-type list (this method is best when used with
      * a large number of connectors, where it would be better to have all of
      * them referenced a single array).
      */
@@ -435,7 +435,7 @@
 
 
     /**
-     * Set compressable mime-type list
+     * Set compressible mime-type list
      * List contains users agents separated by ',' :
      *
      * ie: "text/html,text/xml,text/plain"
@@ -975,7 +975,7 @@
 
         } else if (actionCode == ActionCode.ACTION_ACK) {
 
-            // Acknowlege request
+            // Acknowledge request
 
             // Send a 100 status back if it makes sense (response not committed
             // yet, and client specified an expectation for 100-continue)
@@ -1434,7 +1434,7 @@
 
         if (valueMB == null || valueMB.isNull()) {
             // HTTP/1.0
-            // Default is what the socket tells us. Overriden if a host is
+            // Default is what the socket tells us. Overridden if a host is
             // found/parsed
             request.setServerPort(endpoint.getPort());
             return;
@@ -1518,7 +1518,7 @@
             || (acceptEncodingMB.indexOf("gzip") == -1))
             return false;
 
-        // Check if content is not allready gzipped
+        // Check if content is not already gzipped
         MessageBytes contentEncodingMB =
             response.getMimeHeaders().getValue("Content-Encoding");
 
@@ -1526,7 +1526,7 @@
             && (contentEncodingMB.indexOf("gzip") != -1))
             return false;
 
-        // If force mode, allways compress (test purposes only)
+        // If force mode, always compress (test purposes only)
         if (compressionLevel == 2)
            return true;
 
@@ -1544,7 +1544,7 @@
             }
         }
 
-        // Check if suffisant len to trig the compression
+        // Check if sufficient length to trigger the compression
         long contentLength = response.getContentLengthLong();
         if ((contentLength == -1)
             || (contentLength > compressionMinSize)) {

Modified: tomcat/trunk/java/org/apache/coyote/http11/Http11NioProcessor.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/Http11NioProcessor.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/Http11NioProcessor.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/Http11NioProcessor.java Tue Nov 
17 22:33:58 2009
@@ -551,7 +551,7 @@
 
         } else if (actionCode == ActionCode.ACTION_ACK) {
 
-            // Acknowlege request
+            // Acknowledge request
 
             // Send a 100 status back if it makes sense (response not committed
             // yet, and client specified an expectation for 100-continue)
@@ -990,7 +990,7 @@
 
         if (valueMB == null || valueMB.isNull()) {
             // HTTP/1.0
-            // Default is what the socket tells us. Overriden if a host is
+            // Default is what the socket tells us. Overridden if a host is
             // found/parsed
             request.setServerPort(endpoint.getPort());
             return;

Modified: tomcat/trunk/java/org/apache/coyote/http11/Http11Processor.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/Http11Processor.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/el/parser/AstValue.java (original)
+++ tomcat/trunk/java/org/apache/el/parser/AstValue.java Tue Nov 17 22:33:58 
2009
@@ -63,7 +63,7 @@
         // evaluate expr-a to value-a
         Object base = this.children[0].getValue(ctx);
 
-        // if our base is null (we know there are more properites to evaluate)
+        // if our base is null (we know there are more properties to evaluate)
         if (base == null) {
             throw new PropertyNotFoundException(MessageFactory.get(
                     "error.unreachable.base", this.children[0].getImage()));

Modified: tomcat/trunk/java/org/apache/el/parser/ParseException.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/el/parser/ParseException.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/el/parser/ParseException.java (original)
+++ tomcat/trunk/java/org/apache/el/parser/ParseException.java Tue Nov 17 
22:33:58 2009
@@ -68,7 +68,7 @@
   /**
    * This is the last token that has been consumed successfully.  If
    * this object has been created due to a parse error, the token
-   * followng this token will (therefore) be the first error token.
+   * following this token will (therefore) be the first error token.
    */
   public Token currentToken;
 



---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscr...@tomcat.apache.org
For additional commands, e-mail: dev-h...@tomcat.apache.org

Reply via email to
--- tomcat/trunk/java/org/apache/coyote/http11/Http11Processor.java (original)
+++ tomcat/trunk/java/org/apache/coyote/http11/Http11Processor.java Tue Nov 17 
22:33:58 2009
@@ -347,7 +347,7 @@
 
         } else if (actionCode == ActionCode.ACTION_ACK) {
 
-            // Acknowlege request
+            // Acknowledge request
 
             // Send a 100 status back if it makes sense (response not committed
             // yet, and client specified an expectation for 100-continue)
@@ -945,7 +945,7 @@
 
         if (valueMB == null || valueMB.isNull()) {
             // HTTP/1.0
-            // Default is what the socket tells us. Overriden if a host is
+            // Default is what the socket tells us. Overridden if a host is
             // found/parsed
             request.setServerPort(socket.getLocalPort());
             InetAddress localAddress = socket.getLocalAddress();

Modified: tomcat/trunk/java/org/apache/coyote/http11/InternalAprInputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/InternalAprInputBuffer.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/InternalAprInputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/InternalAprInputBuffer.java Tue 
Nov 17 22:33:58 2009
@@ -326,7 +326,7 @@
     /**
      * End request (consumes leftover bytes).
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     public void endRequest()
         throws IOException {
@@ -345,7 +345,7 @@
      * using it.
      *
      * @throws IOException If an exception occurs during the underlying socket
-     * read operations, or if the given buffer is not big enough to accomodate
+     * read operations, or if the given buffer is not big enough to accommodate
      * the whole line.
      * @return true if data is properly fed; false if no data is available 
      * immediately and thread should be freed
@@ -744,7 +744,7 @@
 
 
     /**
-     * Fill the internal buffer using data from the undelying input stream.
+     * Fill the internal buffer using data from the underlying input stream.
      * 
      * @return false if at end of stream
      */

Modified: 
tomcat/trunk/java/org/apache/coyote/http11/InternalAprOutputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/InternalAprOutputBuffer.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/InternalAprOutputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/InternalAprOutputBuffer.java Tue 
Nov 17 22:33:58 2009
@@ -258,7 +258,7 @@
     /**
      * Flush the response.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     public void flush()
         throws IOException {
@@ -341,7 +341,7 @@
     /**
      * End request.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     public void endRequest()
         throws IOException {
@@ -372,7 +372,7 @@
 
 
     /**
-     * Send an acknoledgement.
+     * Send an acknowledgment.
      */
     public void sendAck()
         throws IOException {
@@ -503,7 +503,7 @@
      * 
      * @param chunk byte chunk
      * @return number of bytes written
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     public int doWrite(ByteChunk chunk, Response res) 
         throws IOException {
@@ -531,7 +531,7 @@
     /**
      * Commit the response.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     protected void commit()
         throws IOException {
@@ -549,7 +549,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied message bytes 
+     * This method will write the contents of the specified message bytes 
      * buffer to the output stream, without filtering. This method is meant to
      * be used to write the response header.
      * 
@@ -571,7 +571,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied message bytes 
+     * This method will write the contents of the specified message bytes 
      * buffer to the output stream, without filtering. This method is meant to
      * be used to write the response header.
      * 
@@ -588,7 +588,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied char 
+     * This method will write the contents of the specified char 
      * buffer to the output stream, without filtering. This method is meant to
      * be used to write the response header.
      * 
@@ -617,7 +617,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied byte 
+     * This method will write the contents of the specified byte 
      * buffer to the output stream, without filtering. This method is meant to
      * be used to write the response header.
      * 
@@ -633,7 +633,7 @@
 
 
     /**
-     * This method will write the contents of the specyfied String to the 
+     * This method will write the contents of the specified String to the 
      * output stream, without filtering. This method is meant to be used to 
      * write the response header.
      * 

Modified: tomcat/trunk/java/org/apache/coyote/http11/InternalInputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/InternalInputBuffer.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/InternalInputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/InternalInputBuffer.java Tue Nov 
17 22:33:58 2009
@@ -69,7 +69,7 @@
      * using it.
      *
      * @throws IOException If an exception occurs during the underlying socket
-     * read operations, or if the given buffer is not big enough to accomodate
+     * read operations, or if the given buffer is not big enough to accommodate
      * the whole line.
      */
     @Override

Modified: tomcat/trunk/java/org/apache/coyote/http11/InternalNioInputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/InternalNioInputBuffer.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/InternalNioInputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/InternalNioInputBuffer.java Tue 
Nov 17 22:33:58 2009
@@ -196,7 +196,7 @@
      * using it.
      *
      * @throws IOException If an exception occurs during the underlying socket
-     * read operations, or if the given buffer is not big enough to accomodate
+     * read operations, or if the given buffer is not big enough to accommodate
      * the whole line.
      * @return true if data is properly fed; false if no data is available 
      * immediately and thread should be freed
@@ -346,7 +346,7 @@
             while (!parsingRequestLineEol) {
                 // Read new bytes if needed
                 if (pos >= lastValid) {
-                    if (!fill(true, false)) //reques line parsing
+                    if (!fill(true, false)) //request line parsing
                         return false;
                 }
         

Modified: 
tomcat/trunk/java/org/apache/coyote/http11/InternalNioOutputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/InternalNioOutputBuffer.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/InternalNioOutputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/InternalNioOutputBuffer.java Tue 
Nov 17 22:33:58 2009
@@ -136,7 +136,7 @@
     /**
      * Flush the response.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      * 
      */
     @Override
@@ -165,7 +165,7 @@
     /**
      * End request.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     @Override
     public void endRequest() throws IOException {
@@ -180,7 +180,7 @@
 
 
     /** 
-     * Send an acknoledgement.
+     * Send an acknowledgment.
      */
     @Override
     public void sendAck() throws IOException {
@@ -236,7 +236,7 @@
     /**
      * Commit the response.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     @Override
     protected void commit()

Modified: tomcat/trunk/java/org/apache/coyote/http11/InternalOutputBuffer.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/InternalOutputBuffer.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/InternalOutputBuffer.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/InternalOutputBuffer.java Tue 
Nov 17 22:33:58 2009
@@ -196,7 +196,7 @@
 
 
     /**
-     * Send an acknoledgement.
+     * Send an acknowledgment.
      */
     @Override
     public void sendAck()
@@ -215,7 +215,7 @@
     /**
      * Commit the response.
      * 
-     * @throws IOException an undelying I/O error occured
+     * @throws IOException an underlying I/O error occurred
      */
     @Override
     protected void commit()

Modified: 
tomcat/trunk/java/org/apache/coyote/http11/filters/VoidInputFilter.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/coyote/http11/filters/VoidInputFilter.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================
--- tomcat/trunk/java/org/apache/coyote/http11/filters/VoidInputFilter.java 
(original)
+++ tomcat/trunk/java/org/apache/coyote/http11/filters/VoidInputFilter.java Tue 
Nov 17 22:33:58 2009
@@ -72,7 +72,7 @@
 
 
     /**
      * Set the associated reauest.
      */
     public void setRequest(Request request) {
     }
@@ -72,7 +72,7 @@
 
     /**
-     * Set the associated reauest.
+     * Set the associated request.
      */
     public void setRequest(Request request) {

Modified: tomcat/trunk/java/org/apache/el/parser/AstValue.java
URL: 
http://svn.apache.org/viewvc/tomcat/trunk/java/org/apache/el/parser/AstValue.java?rev=881578&r1=881577&r2=881578&view=diff
==============================================================================